@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.92
+# FitGallery 0.93
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -51,7 +51,7 @@ $subtotal=0;
 $numimgs=0;
 
 $handle=opendir($dirgal);         # Scan galeries directory
-while ($file = readdir($handle))
+while (($file = readdir($handle))!==false)
 { 
  if ($file != '.' && $file != '..')
   {
