@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.92
+# FitGallery 0.93
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -26,7 +26,7 @@ if ($dirgal=='' || $file=='') exit();
 $mtime=filemtime("$dirgal/$file");
 $handledir=opendir("$dirgal/$file/$dirimgs");
 $primero='x';
-while ($fileimgs = readdir($handledir))
+while (($fileimgs = readdir($handledir))!==false)
   {
     if ($fileimgs != '.' && $fileimgs != '..')
      {
