@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.92
+# FitGallery 0.93
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -56,7 +56,7 @@ $n=0;
 $total=0;
 
 $handle=opendir($ruta);            # Scan image directory
-while ($file = readdir($handle))
+while (($file = readdir($handle))!==false)
 { 
  if ($file != '.' && $file != '..')
   {
